@@ -13,8 +13,12 @@ def slow_control_example():
     logs = slow_logs.get(
         system="tvs",
         folders="g2prod/production/VxWorks/Log/,g3prod/production/VxWorks/Log/,o2prod/production/VxWorks/Log/",
-        start_datetime=datetime(year=2022, month=11, day=30),
-        end_datetime=datetime(year=2022, month=12, day=1),
+        start_datetime=datetime(
+            year=2023, month=2, day=22, hour=1, minute=0, microsecond=741000
+        ),
+        end_datetime=datetime(
+            year=2023, month=2, day=23, hour=3, minute=0, microsecond=741000
+        ),
         area="G2",
     )
     print("execution time: ", time() - start)
@@ -48,6 +52,9 @@ def tcs_trace_example():
     print(logs)
 
 
+from pprint import pprint
+
+
 def pass_log_example():
     """A simple example for the PASS Client, measuring timing of execution, length of return and logs."""
     PASS_LOG_DATA_DIR_ROOT = "/mnt/proscan-fs/"
@@ -58,20 +65,20 @@ def pass_log_example():
     start = time()
     result = api.get(
         area="G2",
-        timestamp=1677020491.722127,
-        # end_date=date(year=2023, month=1, day=25),
-        # start_date=date(year=2023, month=1, day=1),
+        # timestamp=1677020491.722127,
+        end_datetime=datetime(year=2023, month=1, day=3, hour=19),
+        start_datetime=datetime(year=2023, month=1, day=3, hour=17),
     )
 
     logs = [r for r in result]
     print("Excecution time: ", time() - start)
     print(len(logs))
-    print(logs)
+    # pprint(logs)
 
 
 if __name__ == "__main__":
     # Uncomment the example you want to run.
-    # slow_control_example()
+    slow_control_example()
     # tcs_trace_example()
     # pass_log_example()
     pass
