@@ -1,7 +1,7 @@
 import mmap
 import re
 from dataclasses import dataclass
-from datetime import date, datetime
+from datetime import datetime
 from typing import Generator, List, Literal, Optional, Union
 
 import pytz
@@ -65,8 +65,8 @@ class PassClient:
         area: Literal["MP", "G2", "G3", "O2"],
         signal: Optional[str] = None,
         timestamp: Optional[float] = None,
-        start_date: Optional[date] = None,
-        end_date: Optional[date] = None,
+        start_datetime: Optional[datetime] = None,
+        end_datetime: Optional[datetime] = None,
         return_fields: Optional[
             List[Literal["header", "metadata", "event", "pre_events", "post_events"]]
         ] = None,
@@ -87,41 +87,44 @@ class PassClient:
         Yields:
             Generator[InterlockEventData, None, None]: InterlockEventData object with all fields not specified in return_fields None unless return_fields is None that all fields have values.
         """
-        if not (start_date or end_date or timestamp):
+        if not (start_datetime or end_datetime or timestamp):
             raise Exception(
                 "Please provide at least one of timestamp, start_date or end_date!"
             )
 
-        if not start_date or not end_date:
-            start_date = start_date or end_date
-            end_date = start_date
+        if not start_datetime or not end_datetime:
+            start_datetime = start_datetime or end_datetime
+            end_datetime = start_datetime
 
-        if isinstance(start_date, datetime) and isinstance(end_date, datetime):
-            if start_date > end_date:
-                tmp = end_date
-                end_date = start_date
-                start_date = tmp
+        if isinstance(start_datetime, datetime) and isinstance(end_datetime, datetime):
+            if start_datetime > end_datetime:
+                tmp = end_datetime
+                end_datetime = start_datetime
+                start_datetime = tmp
 
         if timestamp:
             _timestamp_dt = pytz.utc.localize(
                 datetime.fromtimestamp(timestamp)
             ).astimezone(pytz.timezone("Europe/Zurich"))
             if isinstance(_timestamp_dt, datetime):
-                start_date = _timestamp_dt.date()
-                end_date = _timestamp_dt.date()
+                start_datetime = _timestamp_dt
+                end_datetime = _timestamp_dt
             else:
                 raise Exception("Invalid Timestamp Format!")
 
         files = get_pass_files(
             folders=get_folders(folders=self.folders, area=area),
-            start_date=start_date,
-            end_date=end_date,
+            start_date=start_datetime.date(),
+            end_date=end_datetime.date(),
             root_dir=self.root_dir,
         )
         for file in files:
             for event in self.search_file(
                 file,
                 mask_str=self.create_mask(timestamp=timestamp, signal=signal),
+                start_datetime=start_datetime,
+                end_datetime=end_datetime,
+                timestamp=timestamp,
                 return_fields=return_fields,
             ):
                 yield event
@@ -130,6 +133,9 @@ class PassClient:
         self,
         file_path: str,
         mask_str: str,
+        start_datetime: datetime,
+        end_datetime: datetime,
+        timestamp: float | None = None,
         return_fields: Optional[
             List[Literal["header", "metadata", "event", "pre_events", "post_events"]]
         ] = None,
@@ -170,7 +176,16 @@ class PassClient:
                         for row in self.row_pattern.finditer(
                             group_dir["pre"].decode(encoding="utf-8")
                         ):
-                            pre_event_list.append(row.groupdict())
+                            pre_row_dict = row.groupdict()
+                            pre_row_dict["datetime"] = str(
+                                datetime.strptime(
+                                    pre_row_dict["datetime"][::-1].replace(".", "", 1)[
+                                        ::-1
+                                    ],
+                                    "%Y-%m-%d %H:%M:%S.%f",
+                                )
+                            )
+                            pre_event_list.append(pre_row_dict)
                     if (
                         "post_events" in return_fields
                         or "event" in return_fields
@@ -180,23 +195,49 @@ class PassClient:
                         for row in self.row_pattern.finditer(
                             group_dir["post"].decode(encoding="utf-8")
                         ):
-                            post_event_list.append(row.groupdict())
+                            post_row_dict = row.groupdict()
+
+                            post_row_dict["datetime"] = str(
+                                datetime.strptime(
+                                    post_row_dict["datetime"][::-1].replace(".", "", 1)[
+                                        ::-1
+                                    ],
+                                    "%Y-%m-%d %H:%M:%S.%f",
+                                )
+                            )
+
+                            post_event_list.append(post_row_dict)
                     metadata = []
                     if post_event_list:
                         metadata = list(post_event_list[0].keys())
                         event = post_event_list.pop(0)
-                    yield InterlockEventData(
-                        header=self.header_pattern.search(
-                            group_dir["header"].decode(encoding="utf-8")
-                        ).groupdict()
-                        if "header" in return_fields
-                        else None,
-                        metadata=metadata if "metadata" in return_fields else None,
-                        event=event if "event" in return_fields else None,
-                        pre_events=pre_event_list
-                        if "pre_events" in return_fields
-                        else None,
-                        post_events=post_event_list
-                        if "post_events" in return_fields
-                        else None,
-                    )
+                        first_event_dt = (
+                            datetime.fromisoformat(pre_event_list[0]["datetime"])
+                            if pre_event_list
+                            else datetime.fromisoformat(event["datetime"])
+                        )
+                        last_event_dt = datetime.fromisoformat(
+                            post_event_list[-1]["datetime"]
+                        )
+
+                    if (
+                        first_event_dt
+                        and first_event_dt > start_datetime.replace(tzinfo=None)
+                        and last_event_dt
+                        and last_event_dt < end_datetime.replace(tzinfo=None)
+                    ) or timestamp:
+                        yield InterlockEventData(
+                            header=self.header_pattern.search(
+                                group_dir["header"].decode(encoding="utf-8")
+                            ).groupdict()
+                            if "header" in return_fields
+                            else None,
+                            metadata=metadata if "metadata" in return_fields else None,
+                            event=event if "event" in return_fields else None,
+                            pre_events=pre_event_list
+                            if "pre_events" in return_fields
+                            else None,
+                            post_events=post_event_list
+                            if "post_events" in return_fields
+                            else None,
+                        )
